@@ -1,14 +1,14 @@
 /*
  * Copyright (C) 2002-2004 Sistina Software, Inc. All rights reserved.
- * Copyright (C) 2004 Red Hat, Inc. All rights reserved.
+ * Copyright (C) 2004-2007 Red Hat, Inc. All rights reserved.
  *
  * This file is part of LVM2.
  *
  * This copyrighted material is made available to anyone wishing to use,
  * modify, copy, or redistribute it subject to the terms and conditions
- * of the GNU General Public License v.2.
+ * of the GNU Lesser General Public License v.2.1.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
@@ -91,8 +91,8 @@ static int _check_device(struct cmd_context *cmd, struct device *dev)
 	return 1;
 }
 
-int lvmdiskscan(struct cmd_context *cmd, int argc __attribute((unused)),
-		char **argv __attribute((unused)))
+int lvmdiskscan(struct cmd_context *cmd, int argc __attribute__((unused)),
+		char **argv __attribute__((unused)))
 {
 	uint64_t size;
 	struct dev_iter *iter;
